@@ -1,8 +1,8 @@
-"""MINimum MONitor - display on stdout: timestamp, RAM and CPU usage, temperature, disk i/o and net i/o
+"""MINimum MONitor - write on stdout (and maybe on log file): timestamp, RAM and CPU usage, temperature, disk i/o and net i/o
 
-minmon displays at fixed time intervals a line in stdout containing:
+minmon writes at fixed time intervals a line in stdout containing:
 
-    1. date 'YYYY-mm-dd' (unless -t/--time is set)
+    1. date 'YYYY-mm-dd' (unless -t/--time-only is set)
     2. time 'HH:MM:SS'
     3. physical Memory % usage and Swap memory % usage
     4. CPU % usage and CPU Temperature in °C
@@ -11,15 +11,15 @@ minmon displays at fixed time intervals a line in stdout containing:
 
 Formats for 3. and 4. are:
 
-    - numeric: two 2-digit decimal numbers, '**' = 100 (unless -g/--graphic is set)
-    - graphic: a linear 0-100 graphic (unless -n/--numeric is set)
+    - numeric: two 2-digit decimal numbers, '**' = 100 (unless -g/--graphic-only is set)
+    - graphic: a linear 0-100 graphic (unless -n/--numeric-only is set)
 
 Formats for 5. an 6. are:
 
-    - numeric: two 5-chars human-readable numbers (unless -g/--graphic is set)
-    - graphic: a logarithmic 1-K-M-G-T graphic (unless -n/--numeric is set)
+    - numeric: two 5-chars human-readable numbers (unless -g/--graphic-only is set)
+    - graphic: a logarithmic 1-K-M-G-T graphic (unless -n/--numeric-only is set)
 
-On overlap in graphics an 'X' is displayed.
+On overlap in graphics an 'X' is written.
 
 As examples of 5-chars human-readable format:
 
@@ -74,5 +74,7 @@ Examples:
 
 """
 
-__version__ = "0.9.4"
+__version__ = "0.9.8"
+
+__requires__ = ["psutil"]
 
