@@ -25,7 +25,7 @@ class args: pass # container for arguments
 # specific functions
 
 def now(date_too=True):
-    'return current time (format = "YYYY-mm-dd HH:MM:SS" if date else "HH:MM:SS"'
+    'return current time (format = "YYYY-mm-dd HH:MM:SS" if date_too else "HH:MM:SS"'
     return "%04d-%02d-%02d %02d:%02d:%02d" % localtime()[:6] if date_too else "%02d:%02d:%02d" % localtime()[3:6]
 
 def strlin(x):
@@ -43,6 +43,10 @@ def hislin(xx, cc, i):
             
 def strlog(x):
     '5-chars display (logarithmic data)'
+    return int2tgmk5(round(x))
+
+def int2tgmk5(x):
+    "convert int x (or TGMK string x) into TGMK5 format (5 chars, rounded to 4 significant digits)"
     x = max(0, round(x))
     if x < 1024:
         return '%5d' % x
@@ -67,40 +71,40 @@ def minmon(argv):
     from .__init__ import __doc__ as description, __version__ as version
     parser = Parser(prog="minmon", formatter_class=Formatter, description=description)
     parser.add_argument("-V", "--version", action="version", version="minmon " + version)
-    parser.add_argument("-s","--sec", type=int, default=1, help="seconds between lines (integer >= 1, default: 1)")
+    parser.add_argument("-s","--seconds", type=int, default=1, help="seconds between lines (integer >= 1, default: 1)")
     parser.add_argument("-t","--time-only", action='store_true',
-                        help="display time only (default: date and time, no effect on CSV format)")
+                        help="write time only, no date (default: date and time, no effect on CSV format)")
     parser.add_argument("-n","--numeric-only", action='store_true',
-                        help="display numeric only (default: numeric and graphic, no effect on CSV format)")
+                        help="write numeric only, no graphic (default: numeric and graphic, no effect on CSV format)")
     parser.add_argument("-g","--graphic-only", action='store_true',
-                        help="display graphic only (default: numeric and graphic, no effect on CSV format)")
-    parser.add_argument("-c","--csv", action='store_true', help="output in CSV format")
-    parser.add_argument("-l","--log", type=str, help=f"write lines into LOG logfile (default path: '~/.minmon')")
+                        help="write graphic only, no numeric (default: numeric and graphic, no effect on CSV format)")
+    parser.add_argument("-c","--csv-format", action='store_true', help="write lines in CSV format")
+    parser.add_argument("-l","--log-file", type=str, help=f"append lines into log file too (default path: '~/.minmon')")
     parser.parse_args(argv[1:], args)
     
     # check arguments 
-    if args.sec < 1:
-        exit(f"minmon: error: --sec is {args.sec} but can't be less than 1")
-    date = not args.time_only
-    numb, grap = ((True, True) if args.numeric_only and args.graphics_only else
-                  (not args.graphics_only, not args.numeric_only))
+    if args.seconds < 1:
+        exit(f"minmon: error: --seconds is {args.seconds} but can't be less than 1")
+    dat = not args.time_only
+    num, gra = ((True, True) if args.numeric_only and args.graphic_only else
+                  (not args.graphic_only, not args.numeric_only))
     
     # perform
-    head = (date * "DATE TIME MEM SWAP CPU TEMP READ WRITE DOWNLOAD UPLOAD" if args.csv else
-        (date * "YYYY-mm-dd " + "HH:MM:SS " +
-        numb * "M% S% " + grap * "0 . . . .50 . . . 100 " +
-        numb * "C% T° " + grap * "0 . . . .50 . . . 100 " +
-        numb * "R-B/s W-B/s " + grap * "1 . . K . . M . . G . . T " +
-        numb * "D-B/s U-B/s " + grap * "1 . . K . . M . . G . . T "))
+    head = (dat * "DATE TIME MEM SWAP CPU TEMP READ WRITE DOWNLOAD UPLOAD" if args.csv_format else
+        (dat * "YYYY-mm-dd " + "HH:MM:SS " +
+        num * "M% S% " + gra * "0 . . . .50 . . . 100 " +
+        num * "C% T° " + gra * "0 . . . .50 . . . 100 " +
+        num * "R-B/s W-B/s " + gra * "1 . . K . . M . . G . . T " +
+        num * "D-B/s U-B/s " + gra * "1 . . K . . M . . G . . T "))
     print(head)
-    if args.log:
-        if "/" not in args.log:
+    if args.log_file:
+        if "/" not in args.log_file:
             path = expanduser("~/.minmon")
             makedirs(path, exist_ok=True)
-        args.log = joinpath(path, args.log)
-        log_file = open(args.log, "a")
+        args.log_file = joinpath(path, args.log_file)
+        log_file = open(args.log_file, "a")
         print(head, file=log_file, flush=True)
-    i, r0, w0, d0, u0, k0, k2 = 0, 0, 0, 0, 0, 0.0, args.sec
+    i, r0, w0, d0, u0, k0, k2 = 0, 0, 0, 0, 0, 0.0, args.seconds
     while True:
         dk = k2 - k0
         k0 = time()
@@ -108,30 +112,31 @@ def minmon(argv):
         s = swap().percent
         m = mem().percent
         c = cpu()
-        t = max(x.current for xx in temp().values() for x in xx)
+        tt = [x.current for xx in temp().values() for x in xx]
+        t = max(tt) if tt else 0
         r1 = disk().read_bytes;  r = max(0, r1 - r0) / dk; r0 = r1
         w1 = disk().write_bytes; w = max(0, w1 - w0) / dk; w0 = w1
         d1 = net().bytes_recv;   d = max(0, d1 - d0) / dk; d0 = d1
         u1 = net().bytes_sent;   u = max(0, u1 - u0) / dk; u0 = u1
         if i > 1:
-            if args.csv:
+            if args.csv_format:
                 line = f"{now()} {m} {s} {c} {t} {r} {w} {d} {u}"
             else:
-                items = [now(date)]
-                if numb: items.extend([strlin(m), strlin(s)])
-                if grap: items.append(hislin([m, s], 'MS', i))
-                if numb: items.extend([strlin(c), strlin(t)])
-                if grap: items.append(hislin([c, t], 'CT', i))
-                if numb: items.extend([strlog(r), strlog(w)])
-                if grap: items.append(hislog([r, w], 'RW', i))
-                if numb: items.extend([strlog(d), strlog(u)])
-                if grap: items.append(hislog([d, u], 'DU', i))
+                items = [now(dat)]
+                if num: items.extend([strlin(m), strlin(s)])
+                if gra: items.append(hislin([m, s], 'MS', i))
+                if num: items.extend([strlin(c), strlin(t)])
+                if gra: items.append(hislin([c, t], 'CT', i))
+                if num: items.extend([strlog(r), strlog(w)])
+                if gra: items.append(hislog([r, w], 'RW', i))
+                if num: items.extend([strlog(d), strlog(u)])
+                if gra: items.append(hislog([d, u], 'DU', i))
                 line = " ".join(items)
             print(line)
-            if args.log:
+            if args.log_file:
                 print(line, file=log_file, flush=True)
         k1 = time()
-        sleep(args.sec - (k1 - k0))
+        sleep(args.seconds - (k1 - k0))
         k2 = time()
             
 def main():
